@@ -26,7 +26,7 @@
 #include <glib/gi18n.h>
 
 #include "gpm-cell-unit.h"
-#include "gpm-debug.h"
+#include "egg-debug.h"
 
 /**
  * gpm_unit_init:
@@ -63,34 +63,34 @@ gpm_cell_unit_print (GpmCellUnit *unit)
 {
 	g_return_val_if_fail (unit != NULL, FALSE);
 
-	gpm_debug ("device         %s", gpm_cell_unit_get_kind_localised (unit, FALSE));
-	gpm_debug ("present        %i", unit->is_present);
-	gpm_debug ("percent        %.1f", unit->percentage);
-	gpm_debug ("is charging    %i", unit->is_charging);
-	gpm_debug ("is discharging %i", unit->is_discharging);
+	egg_debug ("device         %s", gpm_cell_unit_get_kind_localised (unit, FALSE));
+	egg_debug ("present        %i", unit->is_present);
+	egg_debug ("percent        %.1f", unit->percentage);
+	egg_debug ("is charging    %i", unit->is_charging);
+	egg_debug ("is discharging %i", unit->is_discharging);
 	if (unit->charge_current > 0) {
-		gpm_debug ("charge current %i", unit->charge_current);
+		egg_debug ("charge current %i", unit->charge_current);
 	}
 	if (unit->charge_last_full > 0) {
-		gpm_debug ("charge last    %i", unit->charge_last_full);
+		egg_debug ("charge last    %i", unit->charge_last_full);
 	}
 	if (unit->charge_design > 0) {
-		gpm_debug ("charge design  %i", unit->charge_design);
+		egg_debug ("charge design  %i", unit->charge_design);
 	}
 	if (unit->rate > 0) {
-		gpm_debug ("rate           %i", unit->rate);
+		egg_debug ("rate           %i", unit->rate);
 	}
 	if (unit->time_charge > 0) {
-		gpm_debug ("time charge    %i", unit->time_charge);
+		egg_debug ("time charge    %i", unit->time_charge);
 	}
 	if (unit->time_discharge > 0) {
-		gpm_debug ("time discharge %i", unit->time_discharge);
+		egg_debug ("time discharge %i", unit->time_discharge);
 	}
 	if (unit->capacity > 0) {
-		gpm_debug ("capacity       %i", unit->capacity);
+		egg_debug ("capacity       %i", unit->capacity);
 	}
 	if (unit->voltage > 0) {
-		gpm_debug ("voltage        %i", unit->voltage);
+		egg_debug ("voltage        %i", unit->voltage);
 	}
 	return TRUE;
 }
@@ -208,7 +208,7 @@ gpm_cell_unit_get_icon (GpmCellUnit *unit)
 		}
 		filename = g_strdup_printf ("gpm-%s-%s", prefix, index_str);
 	}
-	gpm_debug ("got filename: %s", filename);
+	egg_debug ("got filename: %s", filename);
 	return filename;
 }
 
@@ -335,7 +335,7 @@ gpm_cell_unit_set_kind (GpmCellUnit *unit, const gchar *kind)
 		return TRUE;
 	}
 
-	gpm_warning ("battery type %s unknown", kind);
+	egg_warning ("battery type %s unknown", kind);
 	return FALSE;
 }
 
@@ -354,7 +354,7 @@ gpm_st_cell_unit (GpmSelfTest *test)
 	const gchar *cvalue;
 	gboolean ret;
 
-	if (gpm_st_start (test, "GpmCellUnit", CLASS_AUTO) == FALSE) {
+	if (gpm_st_start (test, "GpmCellUnit") == FALSE) {
 		return;
 	}
 
